﻿/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'colorbutton', 'cs', {
	auto: 'Automaticky',
	bgColorTitle: 'Barva pozadí',
	colors: {
		'000': 'Černá',
		'800000': 'Kaštanová',
		'8B4513': 'Sedlová hněď',
		'2F4F4F': 'Tmavě bledě šedá',
		'008080': 'Čírka',
		'000080': 'Námořnická modř',
		'4B0082': 'Inkoustová',
		'696969': 'Tmavě šedá',
		B22222: 'Pálená cihla',
		A52A2A: 'Hnědá',
		DAA520: 'Zlatý prut',
		'006400': 'Tmavě zelená',
		'40E0D0': 'Tyrkisová',
		'0000CD': 'Středně modrá',
		'800080': 'Purpurová',
		'808080': 'Šedá',
		F00: 'Červená',
		FF8C00: 'Tmavě oranžová',
		FFD700: 'Zlatá',
		'008000': 'Zelená',
		'0FF': 'Azurová',
		'00F': 'Modrá',
		EE82EE: 'Fialová',
		A9A9A9: 'Kalně šedá',
		FFA07A: 'Světle lososová',
		FFA500: 'Oranžová',
		FFFF00: 'Žlutá',
		'00FF00': 'Limetková',
		AFEEEE: 'Bledě tyrkisová',
		ADD8E6: 'Světle modrá',
		DDA0DD: 'Švestková',
		D3D3D3: 'Světle šedá',
		FFF0F5: 'Levandulově ruměnná',
		FAEBD7: 'Antická bílá',
		FFFFE0: 'Světle žlutá',
		F0FFF0: 'Medová rosa',
		F0FFFF: 'Azurová',
		F0F8FF: 'Alenčina modrá',
		E6E6FA: 'Levandulová',
		FFF: 'Bílá',
		'1ABC9C': 'Silná azurová',
		'2ECC71': 'Emeraldová',
		'3498DB': 'Jasně modrá',
		'9B59B6': 'Ametystová',
		'4E5F70': 'Šedomodrá',
		'F1C40F': 'Sytá žlutá',
		'16A085': 'Tmavě azurová',
		'27AE60': 'Tmavě emeraldová',
		'2980B9': 'Silná modrá',
		'8E44AD': 'Tmavě fialová',
		'2C3E50': 'Odsycená modrá',
		'F39C12': 'Oranžová',
		'E67E22': 'Mrkvová',
		'E74C3C': 'Bledě červená',
		'ECF0F1': 'Světle stříbrná',
		'95A5A6': 'Světlě šedoazurová',
		'DDD': 'Světle šedá',
		'D35400': 'Dýňová',
		'C0392B': 'Silná červená',
		'BDC3C7': 'Stříbrná',
		'7F8C8D': 'Šedoazurová',
		'999': 'Tmavošedá'
	},
	more: 'Více barev...',
	panelTitle: 'Barvy',
	textColorTitle: 'Barva textu'
} );
